Documentation — Personis 12.9 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Personis 12.9 documentation »

# Documentation

The documentation for Personis is built using the sphinx, a python based documentation generation tool. Sphinx can make the documentation in many forms. To use the tool you need to install sphinx and its dependancies. A generated pdf version is included in the distribution. If you want to make the pdf version you will need to install a full latex package (eg texlive-full).

To make the various versions the command is:

make html
make latexpdf
make epub

The generated versions are placed in the subdirectory “_build”.

### Navigation

- index
- modules |
- next |
- previous |
- Personis 12.9 documentation »